@@ -84,7 +84,6 @@ class WifiConfApp():
         myWifiConf = WifiConf(access_point, flask_app, self.connected)
         
     def start(self):
-        print(header)
         main = Process(target = myWifiConf.start)
         main.start()
         while True:
@@ -274,14 +273,26 @@ def main():
     argu = parser.parse_args()
     
     if argu.command == 'start':
+        print(header)
+        print("["+bcolor.text("INFO")+"] Loading...")
         args = vars(argu)
 
         access_point = {"wlan":args["wlan"],"inet":args["inet"], "ip":args["ip"], "netmask":args["netmask"], "ssid":args["ssid"], "password":args["password"]}
         flask_app    = {"host":args["host"], "port":args["port"]}
         myWifiConfApp = WifiConfApp(access_point, flask_app)
+        print("["+bcolor.text("OK")+"] App loaded")
         
-        if (args["check"] == "True" and not check_con()) or args["check"] == "False":
-            myWifiConfApp.start()
+        flag=0
+        if args["check"] == "True":
+            print("["+bcolor.text("INFO")+"] Checking network con")
+            if not check_con():
+                print("["+bcolor.text("FAILED")+"] You dont have an internet con")
+                flag=1
+            else:
+                print("["+bcolor.text("OK")+"] You have an internet con\n\tIf you want to force the start, please use the arg --check False")              
+        else:
+            flag=1
+        if flag: myWifiConfApp.start()
 
 if __name__ == "__main__":
     sys.exit(main())
